pub struct UiScriptEventLogEntryV1 {
pub unix_ms: u64,
pub kind: String,
pub step_index: Option<u32>,
pub note: Option<String>,
pub bundle_dir: Option<String>,
pub window: Option<u64>,
pub tick_id: Option<u64>,
pub frame_id: Option<u64>,
pub window_snapshot_seq: Option<u64>,
}Fields
unix_ms: u64kind: Stringstep_index: Option<u32>note: Option<String>bundle_dir: Option<String>window: Option<u64>When available, identifies the window that observed/emitted this event.
tick_id: Option<u64>When available, the app tick id at the time of the event.
frame_id: Option<u64>When available, the app frame id at the time of the event.
window_snapshot_seq: Option<u64>Optional per-window snapshot sequence hint (may be resolved by tooling from bundle.index.json).